@@ -1,9 +1,9 @@
 package ExtUtils::ModuleMaker;
 use strict;
-local $^W = 1;
+use warnings;
 BEGIN {
     use vars qw( $VERSION @ISA );
-    $VERSION = 0.53;
+    $VERSION = 0.56;
     use base qw(
         ExtUtils::ModuleMaker::Defaults
         ExtUtils::ModuleMaker::Initializers
@@ -404,8 +404,8 @@ Inside a Perl program:
 
 =head1 VERSION
 
-This document references version 0.52 of ExtUtils::ModuleMaker, released
-to CPAN on July 04 2014.
+This document references version 0.56 of ExtUtils::ModuleMaker, released
+to CPAN on January 30 2017.
 
 =head1 DESCRIPTION
 
@@ -566,7 +566,7 @@ is off.)
 
 =item * PERMISSIONS
 
-Used to create new directories.  (Default is 0755:  group and world can not
+Used to create new directories.  (Default is 0.56:  group and world can not
 write.)
 
 =item * USAGE_MESSAGE
@@ -1342,6 +1342,10 @@ dave_the_m, randyk, and njh.
 Thanks to Paul M Sirianni for reporting bugs that led to versions 0.48 and
 0.51.
 
+Thanks to Chris Kirke for pointing to reports at
+http://cpants.cpanauthors.org/dist/ExtUtils-ModuleMaker of inconsistent
+$VERSION numbers across the component files.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2002 R. Geoffrey Avery.
